@@ -1,6 +1,6 @@
-import arrow
-from dateutil.tz import gettz
-from django.conf import settings
+from datetime import datetime
+from zoneinfo import ZoneInfo
+
 from django.core.exceptions import ValidationError
 from django.utils import timezone
 from edc_utils import formatted_datetime
@@ -11,8 +11,7 @@ from .protocol import Protocol
 def date_not_before_study_start(value):
     if value:
         protocol = Protocol()
-        tzinfo = gettz(settings.TIME_ZONE)
-        value_utc = arrow.Arrow.fromdate(value, tzinfo).to("utc").datetime
+        value_utc = datetime(*[*value.timetuple()][0:6], tzinfo=ZoneInfo("UTC"))
         if value_utc < protocol.study_open_datetime:
             opened = formatted_datetime(timezone.localtime(protocol.study_open_datetime))
             got = formatted_datetime(timezone.localtime(value_utc))
@@ -25,9 +24,7 @@ def date_not_before_study_start(value):
 def datetime_not_before_study_start(value_datetime):
     if value_datetime:
         protocol = Protocol()
-        value_utc = (
-            arrow.Arrow.fromdatetime(value_datetime, value_datetime.tzinfo).to("utc").datetime
-        )
+        value_utc = value_datetime.astimezone(ZoneInfo("UTC"))
         if value_utc < protocol.study_open_datetime:
             opened = formatted_datetime(timezone.localtime(protocol.study_open_datetime))
             got = formatted_datetime(timezone.localtime(value_utc))
