@@ -1,5 +1,5 @@
-from django.conf import settings
 from django.views.generic.base import TemplateView
+from edc_dashboard.utils import get_bootstrap_version
 from edc_dashboard.view_mixins import EdcViewMixin
 from edc_navbar import NavbarViewMixin
 
@@ -7,7 +7,7 @@ from edc_protocol import Protocol
 
 
 class HomeView(EdcViewMixin, NavbarViewMixin, TemplateView):
-    template_name = f"edc_protocol/bootstrap{settings.EDC_BOOTSTRAP}/home.html"
+    template_name = f"edc_protocol/bootstrap{get_bootstrap_version()}/home.html"
     navbar_name = "edc_protocol"
     navbar_selected_item = "protocol"
 
